@@ -4,4 +4,5 @@ from midi_ddsp import data_handling
 from midi_ddsp import utils
 from midi_ddsp import modules
 from midi_ddsp import hparams_synthesis_generator
-from midi_ddsp.midi_ddsp_synthesize import synthesize_midi
+from midi_ddsp.midi_ddsp_synthesize import synthesize_midi, \
+  load_pretrained_model
